@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'epoll' }
 
@@ -87,6 +87,16 @@ sub gen_get_fd {
     $builder->line("int $fd_var = ${events_var}[$index_var].data.fd;");
 }
 
+# Future/Pool integration - add pool notify fd to epoll
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to epoll */")
+            ->line('ev.events = EPOLLIN;')
+            ->line("ev.data.fd = $notify_fd_var;")
+            ->line("epoll_ctl($loop_var, EPOLL_CTL_ADD, $notify_fd_var, &ev);");
+}
+
 1;
 
 __END__
