@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'event_ports' }
 
@@ -120,6 +120,16 @@ sub gen_rearm_listen {
       ->line("port_associate($loop_var, PORT_SOURCE_FD, $listen_fd_var, POLLIN, NULL);");
 }
 
+# Future/Pool integration - add pool notify fd to event port
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to event port */")
+            ->if("port_associate($loop_var, PORT_SOURCE_FD, $notify_fd_var, POLLIN, (void*)(intptr_t)$notify_fd_var) < 0")
+              ->line('perror("port_associate pool notify");')
+            ->endif;
+}
+
 1;
 
 __END__
