@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'iocp' }
 
@@ -183,6 +183,23 @@ sub gen_cleanup {
       ->line('WSACleanup();');
 }
 
+# Future/Pool integration - IOCP uses different mechanism for pool notify
+# On Windows, pool uses a pipe which can be added to IOCP via overlapped read
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to IOCP */")
+            ->line("HANDLE iocp_handle = (HANDLE)(intptr_t)$loop_var;")
+            ->line("CreateIoCompletionPort((HANDLE)$notify_fd_var, iocp_handle, (ULONG_PTR)$notify_fd_var, 0);")
+            ->line('PER_IO_DATA* pool_io = (PER_IO_DATA*)calloc(1, sizeof(PER_IO_DATA));')
+            ->line('pool_io->op_type = 4;')  # New type for pool notify
+            ->line("pool_io->socket = $notify_fd_var;")
+            ->line('pool_io->wsa_buf.buf = pool_io->buffer;')
+            ->line('pool_io->wsa_buf.len = 1;')
+            ->line('DWORD flags = 0;')
+            ->line("ReadFile((HANDLE)$notify_fd_var, pool_io->buffer, 1, NULL, &pool_io->overlapped);");
+}
+
 1;
 
 __END__
