@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'io_uring' }
 
@@ -172,6 +172,19 @@ sub gen_cleanup {
     ->endif;
 }
 
+# Future/Pool integration - add pool notify fd via poll on the fd
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to io_uring via poll */")
+            ->line('sqe = io_uring_get_sqe(&ring);')
+            ->if('sqe')
+              ->line("io_uring_prep_poll_add(sqe, $notify_fd_var, POLLIN);")
+              ->line("io_uring_sqe_set_data(sqe, (void*)(uintptr_t)(0x40000000 | $notify_fd_var));")
+              ->line('io_uring_submit(&ring);')
+            ->endif;
+}
+
 1;
 
 __END__
