@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'kqueue' }
 
@@ -90,6 +90,15 @@ sub gen_get_fd {
     $builder->line("int $fd_var = (int)${events_var}[$index_var].ident;");
 }
 
+# Future/Pool integration - add pool notify fd to kqueue
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to kqueue */")
+            ->line("EV_SET(&ev, $notify_fd_var, EVFILT_READ, EV_ADD | EV_ENABLE, 0, 0, NULL);")
+            ->line("kevent($loop_var, &ev, 1, NULL, 0, NULL);");
+}
+
 1;
 
 __END__
