@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'poll' }
 
@@ -105,6 +105,18 @@ sub gen_get_fd {
       ->line("int $fd_var = poll_fds[$index_var].fd;");
 }
 
+# Future/Pool integration - add pool notify fd to poll array
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to poll array */")
+            ->if('poll_nfds < MAX_POLL_FDS')
+              ->line("poll_fds[poll_nfds].fd = $notify_fd_var;")
+              ->line('poll_fds[poll_nfds].events = POLLIN;')
+              ->line('poll_nfds++;')
+            ->endif;
+}
+
 1;
 
 __END__
