@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Hypersonic::Event::Role - Base class for event backends
 #
@@ -88,6 +88,33 @@ sub gen_cleanup {
     # Default: no-op
 }
 
+# ============================================================
+# Future/Pool Integration Methods
+# ============================================================
+
+# Generate code to add the Future pool notify fd to the event loop
+# Called during event loop setup when pool is available
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+    # Default: use gen_add
+    $class->gen_add($builder, $loop_var, $notify_fd_var);
+}
+
+# Generate code to check if the current fd is the pool notify fd
+# Should set a variable indicating this is a pool notification
+sub gen_check_pool_notify {
+    my ($class, $builder, $fd_var, $notify_fd_var, $is_pool_var) = @_;
+    $builder->line("int $is_pool_var = ($fd_var == $notify_fd_var);");
+}
+
+# Generate code to process pool notifications (call pool_process_ready)
+sub gen_process_pool_ready {
+    my ($class, $builder) = @_;
+    $builder->line('/* Process completed async operations */')
+            ->line('extern int xs_pool_process_ready(pTHX_ CV *cv);')
+            ->line('xs_pool_process_ready(aTHX_ NULL);');
+}
+
 # ============================================================
 # Utility Methods for Backends
 # ============================================================
