@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub name { 'select' }
 
@@ -130,6 +130,17 @@ sub gen_cleanup {
     }
 }
 
+# Future/Pool integration - add pool notify fd to master set
+sub gen_add_pool_notify {
+    my ($class, $builder, $loop_var, $notify_fd_var) = @_;
+
+    $builder->line("/* Add pool notify fd to select master set */")
+            ->line("FD_SET($notify_fd_var, &master_read_fds);")
+            ->if("$notify_fd_var > max_fd")
+              ->line("max_fd = $notify_fd_var;")
+            ->endif;
+}
+
 1;
 
 __END__
